
[![](https://codecov.io/gh/whoopnip/bibtex-gen/branch/master/graph/badge.svg)](https://codecov.io/gh/whoopnip/bibtex-gen)

# bibtex-gen

## Overview

Generate BibTeX reference objects from DOIs and strings

## Getting Started

Install `bibtex_gen`:

```
pip install bibtex_gen
```

A simple example:

```python
import bibtex_gen

# Do something with bibtex_gen
```

## Links

See the 
[documentation here.](
https://whoopnip.github.io/bibtex-gen/
)
